var NAVTREEINDEX10 =
{
"group__API__Threads.html#ga670ae411d7536934d784c88c6d11177c":[25,3,28],
"group__API__Threads.html#ga707b1afc766917d4ddbbe19e5569359b":[25,3,23],
"group__API__Threads.html#ga7cf8cbee2a33b4714cf37724f657bd4a":[25,3,15],
"group__API__Threads.html#ga81126f750a75beef8a9679dd261e1bd2":[25,3,21],
"group__API__Threads.html#ga85907c2f14430e01fea27280ed3ac2ae":[25,3,41],
"group__API__Threads.html#ga8cda60ccc235761b6fea9ec2204da362":[25,3,3],
"group__API__Threads.html#ga8d9b7c62dc30af6fdf84acf0367e2b43":[25,3,58],
"group__API__Threads.html#ga8fd0aa9fa9c38abbdcb91047eccf34e5":[25,3,38],
"group__API__Threads.html#ga9d53e88546b413acd8b1312acd885966":[25,3,29],
"group__API__Threads.html#ga9ef49f133fa6f1374769aab8a4ff9474":[25,3,65],
"group__API__Threads.html#gaa0871b23fee2d5cfa1e4930108b53708":[25,3,25],
"group__API__Threads.html#gaa8d07e258b61aa10fc8ce2111f4a37a9":[25,3,67],
"group__API__Threads.html#gaad19009cc7f31a2b5bd8bc3e3d000e45":[25,3,39],
"group__API__Threads.html#gab1d60ac7acd857f056de5d9cdd3b8b93":[25,3,2],
"group__API__Threads.html#gab1f13e8c7f4e9c7a93e35ffa5f3c8925":[25,3,7],
"group__API__Threads.html#gab24c9ad484185c1b0fc2518a27824041":[25,3,11],
"group__API__Threads.html#gab3f630ba782864f80fb7d8fceb7db399":[25,3,60],
"group__API__Threads.html#gab522d9c9ae9747db8123344f49421725":[25,3,62],
"group__API__Threads.html#gab99612af964c7e92d99e3fcc9513c909":[25,3,4],
"group__API__Threads.html#gaba0e781d7d8a22c313200edaa9ec59f9":[25,3,17],
"group__API__Threads.html#gac1f65845c0c1c76e65c63fc5174ff5cb":[25,3,8],
"group__API__Threads.html#gac59327fea4e8f540a378c41b1157d367":[25,3,57],
"group__API__Threads.html#gac5bf366536c4f722dec41da48618b937":[25,3,66],
"group__API__Threads.html#gac83bf1cce7a509b76cae9e191fb39bb4":[25,3,27],
"group__API__Threads.html#gac93d8e7fcb44d354421a77b1c0bc9569":[25,3,26],
"group__API__Threads.html#gacabc76c4b40c66603b5d417d7039439a":[25,3,5],
"group__API__Threads.html#gad37f49e0fb051b7a3a66208a4bc67397":[25,3,22],
"group__API__Threads.html#gadcaa2002f0cd921e66afca18a63ccb88":[25,3,45],
"group__API__Threads.html#gadda164742adc172cb99860c88363ecd8":[25,3,34],
"group__API__Threads.html#gadecb508e5f50f8cf5c90626bdaca17fa":[25,3,35],
"group__API__Threads.html#gae024574a5ff66361d2b00f10924dbf3a":[25,3,10],
"group__API__Threads.html#gaea6e537f9a02061690e845082158b3b4":[25,3,0],
"group__API__Threads.html#gaebaf9c865b4a20d01a6017a11053c223":[25,3,37],
"group__API__Threads.html#gaede3f824ce3ecf6079987a68da9eb621":[25,3,13],
"group__API__Threads.html#gaf16bdf5df80097a4fbd08b23af68f829":[25,3,51],
"group__API__Threads.html#gafafe5e882f4be0f494a978dc0853d527":[25,3,48],
"group__API__Threads.html#gaff16a92b547683cc3891dfb1faca1e3a":[25,3,40],
"group__API__Threads.html#gaffe50be0f786d9a529a9946171469879":[25,3,31],
"group__API__Toolbox.html":[25,35],
"group__API__Toolbox.html#ga057b12b615ce9e8a1fe7b5e10d9a5c2e":[25,35,10],
"group__API__Toolbox.html#ga05ac0dda104331f57d85823a4f9318ce":[25,35,12],
"group__API__Toolbox.html#ga07b2628bd6680fe49d92c7f816d7ce53":[25,35,21],
"group__API__Toolbox.html#ga10dac0e97a9c6bcc9ae042e067c508ae":[25,35,14],
"group__API__Toolbox.html#ga1b41d799a04a1d6483e982ffb2f74432":[25,35,19],
"group__API__Toolbox.html#ga214c60ee1b6cbc27ab08ba6f339ef8e5":[25,35,8],
"group__API__Toolbox.html#ga230129f89ca986b143c6b059a9229fb7":[25,35,4],
"group__API__Toolbox.html#ga23742c6fca8b5386e1f3e3f7bbf3a692":[25,35,1],
"group__API__Toolbox.html#ga3a4d1fb56668323d4f44c18f6a6dfb3f":[25,35,16],
"group__API__Toolbox.html#ga4268950ebf63c0f1dabcfd0cd8808067":[25,35,17],
"group__API__Toolbox.html#ga4456c2db2cc8df7c98d62ecc21b2bd1d":[25,35,2],
"group__API__Toolbox.html#ga4fc771a29d7dc0e826da42777edbcf15":[25,35,0],
"group__API__Toolbox.html#ga71e28fc2a0a5267bc7edc0909d9d5117":[25,35,9],
"group__API__Toolbox.html#ga725920b5267625bff19f49219ff2d4d8":[25,35,13],
"group__API__Toolbox.html#ga7df091d95d10b854c16cd1cd65cf7508":[25,35,6],
"group__API__Toolbox.html#ga9804db3e8ffb845492154f63e7d6ae95":[25,35,7],
"group__API__Toolbox.html#ga9e7c20a6cdce868976a0046206b104e6":[25,35,3],
"group__API__Toolbox.html#gaa3503ea5efd00806a0f9234f033e6ea1":[25,35,18],
"group__API__Toolbox.html#gaa5363993d4f519517316ccf9dc47a7bb":[25,35,20],
"group__API__Toolbox.html#gabb6941113e19ee4045a014943cd62aae":[25,35,15],
"group__API__Toolbox.html#gae07407908792f54312150228d70dbece":[25,35,5],
"group__API__Toolbox.html#gae8c513ecd1a5bd87a7bdd71260c49ffc":[25,35,11],
"group__API__Transactions.html":[25,7],
"group__API__Transactions.html#ga4a31681d2f0cb458570d4acb50ee1b0f":[25,7,2],
"group__API__Transactions.html#ga85c17fa938cac5969d6e2872c660a1a6":[25,7,0],
"group__API__Transactions.html#gac33728c32906466d0aac40646aa2614d":[25,7,1],
"group__API__Tree.html":[25,46],
"group__API__Tree.html#structstarpu__tree":[25,46,0],
"group__API__Versioning.html":[25,5],
"group__API__Versioning.html#ga43895a109dc6f27de709208f460b321d":[25,5,2],
"group__API__Versioning.html#ga61698352a3ca7e28b4bcdd8bcad8d8cc":[25,5,0],
"group__API__Versioning.html#ga847f129c7b859f46c8bd69c9c8cbcde5":[25,5,1],
"group__API__Versioning.html#gaa9151820d2ef6a8231b510b4b3c19ca4":[25,5,3],
"group__API__Workers.html":[25,18],
"group__API__Workers.html#a0d213fc6e036df7424e05c30bfca22c4":[25,18,1,0],
"group__API__Workers.html#a10961e3af7749f812b744dbd9f85da96":[25,18,1,1],
"group__API__Workers.html#a1782f997e873faa64de39cf4bd570661":[25,18,1,6],
"group__API__Workers.html#a26ad74518560f75a4cd9e1ee0cb2eb7c":[25,18,1,8],
"group__API__Workers.html#a3460c754c642b2244d4c2ceb98101ece":[25,18,0,0],
"group__API__Workers.html#a6595f14b6715e60d2444f4cd09b9d73f":[25,18,1,3],
"group__API__Workers.html#ab92e3de048f56a4c2f59fa804594c339":[25,18,1,4],
"group__API__Workers.html#acbe5dc434c779fec539a427b8e8ab1aa":[25,18,1,2],
"group__API__Workers.html#adf52d25f085ea1f6fe2b982b3439b73f":[25,18,1,7],
"group__API__Workers.html#ae039a760cdd80c0d91bcc4c4da9ebb74":[25,18,1,5],
"group__API__Workers.html#ae260b3aeb9f58a98d7adb70eea8b851c":[25,18,1,9],
"group__API__Workers.html#ga03d66f459ebae08349fa50042fe37808":[25,18,46],
"group__API__Workers.html#ga0c9b9b7f5195cb8cbc5ee1223ec0f264":[25,18,34],
"group__API__Workers.html#ga0dd6ff2d77c6a520a6cc4c051eb40bfa":[25,18,18],
"group__API__Workers.html#ga1056809a8cd464002ed4cad02cec33e4":[25,18,67],
"group__API__Workers.html#ga130075042017ad3794ba2321743088c6":[25,18,50],
"group__API__Workers.html#ga1552f16bc4b25d839efc732180efa130":[25,18,43],
"group__API__Workers.html#ga173d616aefe98c33a47a847fd2fca37d":[25,18,9],
"group__API__Workers.html#ga177bffe36c7df3f91aaebe2dd03b8cda":[25,18,2],
"group__API__Workers.html#ga178dd465219373d9da366fff593d56fa":[25,18,17],
"group__API__Workers.html#ga1c6e6bcceeb1c5d4edafa9d933d15cc2":[25,18,23],
"group__API__Workers.html#ga1c9cefba8ede1b63cef4a617a73f7d2c":[25,18,54],
"group__API__Workers.html#ga1d20d159f519df135fb1ac954a29bccf":[25,18,58],
"group__API__Workers.html#ga21213e018976d3876c85d3ca9ac1dff9":[25,18,31],
"group__API__Workers.html#ga2b75b2600f85996e943ece2631971c62":[25,18,13],
"group__API__Workers.html#ga2c930d982bacf4bf4dce015ab2d61123":[25,18,66],
"group__API__Workers.html#ga35c8908fd60c0407901872b25a8a88da":[25,18,68],
"group__API__Workers.html#ga389142e108345483dc8c0bf07465263c":[25,18,49],
"group__API__Workers.html#ga38c0b1858730fec2211991147a964910":[25,18,69],
"group__API__Workers.html#ga39b7e2b82022313535c7b0015c2a0176":[25,18,45],
"group__API__Workers.html#ga3a6a9eddecb3e97b3c37e151003ea7c2":[25,18,32],
"group__API__Workers.html#ga3c4c7e122c29d884fe1674434b69cf52":[25,18,22],
"group__API__Workers.html#ga3f985e55d355aa7b1c83471230b37a39":[25,18,39],
"group__API__Workers.html#ga3fa9784ddcf3fc9f496e33fe4cad54ce":[25,18,38],
"group__API__Workers.html#ga40eea17cbbabcb0eed906d0b50604ed2":[25,18,63],
"group__API__Workers.html#ga45611e9799d1c32e826c5f2f6a642c65":[25,18,51],
"group__API__Workers.html#ga479f8ed78324dca80ad746d0fee5d832":[25,18,7],
"group__API__Workers.html#ga4998e4e1dfa0d121059c60f790496a03":[25,18,24],
"group__API__Workers.html#ga53bac558c693f8cfdeef94bc6b64ab0b":[25,18,53],
"group__API__Workers.html#ga5728fe0e4be069e45c4cd0ac0319d8a0":[25,18,47],
"group__API__Workers.html#ga57687262112024abc0082b01b72ff0e8":[25,18,59],
"group__API__Workers.html#ga5877310a0fae5f20967027fcb214c7aa":[25,18,37],
"group__API__Workers.html#ga60b4a796a3dba40e5159158750805bf2":[25,18,25],
"group__API__Workers.html#ga6312aa4b12ce7e06fe391bcafda6796a":[25,18,14],
"group__API__Workers.html#ga65ceee59fa79646aa5d2447eb2b17037":[25,18,11],
"group__API__Workers.html#ga6f3fbb6e918d0135ccb68473a8ee5ca1":[25,18,8],
"group__API__Workers.html#ga76d913164202fc836d6f76811371db0c":[25,18,71],
"group__API__Workers.html#ga7703495d0659819cef60634c1b704af2":[25,18,33],
"group__API__Workers.html#ga7de6654141ce89ea83c3aba60486396e":[25,18,52],
"group__API__Workers.html#ga80b06886ee8a4c0e99b09ab638113af3":[25,18,10],
"group__API__Workers.html#ga81227c4d4758d9f1b4a12cc3ecfc8a96":[25,18,55],
"group__API__Workers.html#ga832ce3b4d20a3f94da0d681965e8eea1":[25,18,41],
"group__API__Workers.html#ga8c4e370ff327c38a3ec79c9249ab233a":[25,18,15],
"group__API__Workers.html#ga8dc923de752528ca92c129c00af3703e":[25,18,70],
"group__API__Workers.html#ga9381b07c96aa7d1d0e6edeb338b2fd94":[25,18,29],
"group__API__Workers.html#ga95b8a935e52957f51659be8abad46668":[25,18,35],
"group__API__Workers.html#ga9b2541fc1a20c4c486c499af01a3283c":[25,18,60],
"group__API__Workers.html#gaa6e5fd90ba1b431ed025006d190fb421":[25,18,5],
"group__API__Workers.html#gaa7a73dac05f65d5760abf29016e251f0":[25,18,3],
"group__API__Workers.html#gaad05388dbafdd5397ebe080913a7b0c8":[25,18,19],
"group__API__Workers.html#gaafe3ee2f7b074f95e8bc79eeabda0f0f":[25,18,4],
"group__API__Workers.html#gab0ffe5622c5980444226f1ed8d6fee71":[25,18,27],
"group__API__Workers.html#gab48ee9207771b65673f5bb18885c8a7c":[25,18,12],
"group__API__Workers.html#gab568e2368c11f9fb362f04264ad4cd04":[25,18,65],
"group__API__Workers.html#gabb530cc7597d5a135b900760f45c9cde":[25,18,61],
"group__API__Workers.html#gac043c52077692456604a2f2f161b86ba":[25,18,57],
"group__API__Workers.html#gac5ac7db6daab005d9c36c2481d984b66":[25,18,40],
"group__API__Workers.html#gac6d06f4e22b63bf50bc8e836cf16f81f":[25,18,21],
"group__API__Workers.html#gacb9d262c066c047ae55f691adc876db3":[25,18,16],
"group__API__Workers.html#gacdc94f67f203028dbfc25a2e8b588bb5":[25,18,62],
"group__API__Workers.html#gace5e9c1624f4d6449b22857b38326e9e":[25,18,73],
"group__API__Workers.html#gad3f993a7ab14f16e51406a7da3c634f2":[25,18,64],
"group__API__Workers.html#gad58c5fb79e34ec4bf2689213ee4528c3":[25,18,36],
"group__API__Workers.html#gad7c443d1341e4976d63fb5d77e74bf09":[25,18,6],
"group__API__Workers.html#gae1ab43056f2c28ed3826e80c5a86a0fc":[25,18,26],
"group__API__Workers.html#gae1ea590928704bb8578db76422c4022c":[25,18,72],
"group__API__Workers.html#gae35a841f996b8758f3d0ce2ac2d066a5":[25,18,30],
"group__API__Workers.html#gae5eabb8523f44bc9ac81031e05f99f66":[25,18,44],
"group__API__Workers.html#gae6166f338640d033b740f5c8008b851b":[25,18,28],
"group__API__Workers.html#gaec386585a6952f9c7fb47621844fbb39":[25,18,20],
"group__API__Workers.html#gaf48e8da13c523a7a9f2530349ddda29e":[25,18,56],
"group__API__Workers.html#gafc5f2fe263ec932eaf48ab0d313bc322":[25,18,42],
"group__API__Workers.html#gafcf67f47d1addfbe6ca143f04065b00c":[25,18,48],
"group__API__Workers.html#gga173d616aefe98c33a47a847fd2fca37da26ced4e9dfc43343f0b442bb465218a9":[25,18,9,1],
"group__API__Workers.html#gga173d616aefe98c33a47a847fd2fca37da5e57c05c04fb13b5383006cfb7719bf5":[25,18,9,4],
"group__API__Workers.html#gga173d616aefe98c33a47a847fd2fca37da6afc9f886af7206833d473e20d2343e7":[25,18,9,6],
"group__API__Workers.html#gga173d616aefe98c33a47a847fd2fca37da7fa269b896814504abcf227388233d1f":[25,18,9,0],
"group__API__Workers.html#gga173d616aefe98c33a47a847fd2fca37dac8fa4358a1bbed68129ebc834ee32bc1":[25,18,9,3],
"group__API__Workers.html#gga173d616aefe98c33a47a847fd2fca37dad2e8eb63bb5c17adcf205af07deff98c":[25,18,9,2],
"group__API__Workers.html#gga173d616aefe98c33a47a847fd2fca37dadbf5857b92809e4c81cc7a8b4f7d34c3":[25,18,9,8],
"group__API__Workers.html#gga173d616aefe98c33a47a847fd2fca37dadc9efedf9b6e4e6ce71d8522f6c1206f":[25,18,9,7],
"group__API__Workers.html#gga173d616aefe98c33a47a847fd2fca37daf5a63ea6a5480c1a6bcf65db1a4c8761":[25,18,9,5],
"group__API__Workers.html#gga6f3fbb6e918d0135ccb68473a8ee5ca1a0f41ef0eff3429abe8480b285c8e37d9":[25,18,8,8],
"group__API__Workers.html#gga6f3fbb6e918d0135ccb68473a8ee5ca1a25ef72894680c188a842f2cefebeb673":[25,18,8,7],
"group__API__Workers.html#gga6f3fbb6e918d0135ccb68473a8ee5ca1a30be863a2bfc1c5b98c9f2ccdf62394a":[25,18,8,6],
"group__API__Workers.html#gga6f3fbb6e918d0135ccb68473a8ee5ca1a3bb8e78a9fffd443b2e87d648a1c7531":[25,18,8,3],
"group__API__Workers.html#gga6f3fbb6e918d0135ccb68473a8ee5ca1a4f0b10cf4c5fb6333b9e3906b81cc5a6":[25,18,8,1],
"group__API__Workers.html#gga6f3fbb6e918d0135ccb68473a8ee5ca1a59908ef1a8ddbae47f0ff0ed704678af":[25,18,8,4],
"group__API__Workers.html#gga6f3fbb6e918d0135ccb68473a8ee5ca1aa081477174eb3510759873f06bf5f585":[25,18,8,5],
"group__API__Workers.html#gga6f3fbb6e918d0135ccb68473a8ee5ca1ad203062edfbde734600e982a54fe5ad2":[25,18,8,9],
"group__API__Workers.html#gga6f3fbb6e918d0135ccb68473a8ee5ca1adba8e3eb8cbe7ba83bbd4c1707fc5ffd":[25,18,8,0],
"group__API__Workers.html#gga6f3fbb6e918d0135ccb68473a8ee5ca1aeb7a39d95a8ff63c3d7e1fc479fe923f":[25,18,8,2],
"group__API__Workers.html#gga80b06886ee8a4c0e99b09ab638113af3a2542d005328b674a7479c0c49068f914":[25,18,10,0],
"group__API__Workers.html#gga80b06886ee8a4c0e99b09ab638113af3a574a8ee7f0fc8414cd16767c88481d26":[25,18,10,1],
"group__API__Workers.html#structstarpu__sched__ctx__iterator":[25,18,0],
"group__API__Workers.html#structstarpu__worker__collection":[25,18,1],
"index.html":[],
"interfacefstarpu__mod_1_1fstarpu__arbiter__create.html":[26,0,0,0],
"interfacefstarpu__mod_1_1fstarpu__arbiter__create.html":[27,0,0,0],
"interfacefstarpu__mod_1_1fstarpu__arbiter__destroy.html":[27,0,0,1],
"interfacefstarpu__mod_1_1fstarpu__arbiter__destroy.html":[26,0,0,1],
"interfacefstarpu__mod_1_1fstarpu__asynchronous__copy__disabled.html":[27,0,0,2],
"interfacefstarpu__mod_1_1fstarpu__asynchronous__copy__disabled.html":[26,0,0,2],
"interfacefstarpu__mod_1_1fstarpu__asynchronous__cuda__copy__disabled.html":[27,0,0,3],
"interfacefstarpu__mod_1_1fstarpu__asynchronous__cuda__copy__disabled.html":[26,0,0,3],
"interfacefstarpu__mod_1_1fstarpu__asynchronous__opencl__copy__disabled.html":[27,0,0,4],
"interfacefstarpu__mod_1_1fstarpu__asynchronous__opencl__copy__disabled.html":[26,0,0,4],
"interfacefstarpu__mod_1_1fstarpu__block__data__register.html":[26,0,0,5],
"interfacefstarpu__mod_1_1fstarpu__block__data__register.html":[27,0,0,5],
"interfacefstarpu__mod_1_1fstarpu__block__filter__block.html":[27,0,0,6],
"interfacefstarpu__mod_1_1fstarpu__block__filter__block.html":[26,0,0,6],
"interfacefstarpu__mod_1_1fstarpu__block__filter__block__shadow.html":[27,0,0,7],
"interfacefstarpu__mod_1_1fstarpu__block__filter__block__shadow.html":[26,0,0,7],
"interfacefstarpu__mod_1_1fstarpu__block__filter__depth__block.html":[26,0,0,8],
"interfacefstarpu__mod_1_1fstarpu__block__filter__depth__block.html":[27,0,0,8],
"interfacefstarpu__mod_1_1fstarpu__block__filter__depth__block__shadow.html":[27,0,0,9],
"interfacefstarpu__mod_1_1fstarpu__block__filter__depth__block__shadow.html":[26,0,0,9],
"interfacefstarpu__mod_1_1fstarpu__block__filter__vertical__block.html":[27,0,0,10],
"interfacefstarpu__mod_1_1fstarpu__block__filter__vertical__block.html":[26,0,0,10],
"interfacefstarpu__mod_1_1fstarpu__block__filter__vertical__block__shadow.html":[26,0,0,11],
"interfacefstarpu__mod_1_1fstarpu__block__filter__vertical__block__shadow.html":[27,0,0,11],
"interfacefstarpu__mod_1_1fstarpu__block__get__ldy.html":[26,0,0,12],
"interfacefstarpu__mod_1_1fstarpu__block__get__ldy.html":[27,0,0,12],
"interfacefstarpu__mod_1_1fstarpu__block__get__ldz.html":[26,0,0,13],
"interfacefstarpu__mod_1_1fstarpu__block__get__ldz.html":[27,0,0,13],
"interfacefstarpu__mod_1_1fstarpu__block__get__nx.html":[26,0,0,14],
"interfacefstarpu__mod_1_1fstarpu__block__get__nx.html":[27,0,0,14],
"interfacefstarpu__mod_1_1fstarpu__block__get__ny.html":[26,0,0,15],
"interfacefstarpu__mod_1_1fstarpu__block__get__ny.html":[27,0,0,15],
"interfacefstarpu__mod_1_1fstarpu__block__get__nz.html":[26,0,0,16],
"interfacefstarpu__mod_1_1fstarpu__block__get__nz.html":[27,0,0,16],
"interfacefstarpu__mod_1_1fstarpu__block__get__ptr.html":[26,0,0,17],
"interfacefstarpu__mod_1_1fstarpu__block__get__ptr.html":[27,0,0,17],
"interfacefstarpu__mod_1_1fstarpu__block__ptr__register.html":[26,0,0,18],
"interfacefstarpu__mod_1_1fstarpu__block__ptr__register.html":[27,0,0,18],
"interfacefstarpu__mod_1_1fstarpu__codelet__add__buffer.html":[27,0,0,19],
"interfacefstarpu__mod_1_1fstarpu__codelet__add__buffer.html":[26,0,0,19],
"interfacefstarpu__mod_1_1fstarpu__codelet__add__cpu__func.html":[26,0,0,20],
"interfacefstarpu__mod_1_1fstarpu__codelet__add__cpu__func.html":[27,0,0,20],
"interfacefstarpu__mod_1_1fstarpu__codelet__add__cuda__flags.html":[27,0,0,21],
"interfacefstarpu__mod_1_1fstarpu__codelet__add__cuda__flags.html":[26,0,0,21],
"interfacefstarpu__mod_1_1fstarpu__codelet__add__cuda__func.html":[27,0,0,22],
"interfacefstarpu__mod_1_1fstarpu__codelet__add__cuda__func.html":[26,0,0,22],
"interfacefstarpu__mod_1_1fstarpu__codelet__add__opencl__flags.html":[26,0,0,23],
"interfacefstarpu__mod_1_1fstarpu__codelet__add__opencl__flags.html":[27,0,0,23],
"interfacefstarpu__mod_1_1fstarpu__codelet__add__opencl__func.html":[27,0,0,24],
"interfacefstarpu__mod_1_1fstarpu__codelet__add__opencl__func.html":[26,0,0,24],
"interfacefstarpu__mod_1_1fstarpu__codelet__allocate.html":[27,0,0,25],
"interfacefstarpu__mod_1_1fstarpu__codelet__allocate.html":[26,0,0,25],
"interfacefstarpu__mod_1_1fstarpu__codelet__display__stats.html":[27,0,0,26],
"interfacefstarpu__mod_1_1fstarpu__codelet__display__stats.html":[26,0,0,26],
"interfacefstarpu__mod_1_1fstarpu__codelet__free.html":[27,0,0,27],
"interfacefstarpu__mod_1_1fstarpu__codelet__free.html":[26,0,0,27],
"interfacefstarpu__mod_1_1fstarpu__codelet__init.html":[27,0,0,28],
"interfacefstarpu__mod_1_1fstarpu__codelet__init.html":[26,0,0,28],
"interfacefstarpu__mod_1_1fstarpu__codelet__set__color.html":[26,0,0,29],
"interfacefstarpu__mod_1_1fstarpu__codelet__set__color.html":[27,0,0,29],
"interfacefstarpu__mod_1_1fstarpu__codelet__set__energy__model.html":[27,0,0,30],
"interfacefstarpu__mod_1_1fstarpu__codelet__set__energy__model.html":[26,0,0,30],
"interfacefstarpu__mod_1_1fstarpu__codelet__set__flags.html":[27,0,0,31],
"interfacefstarpu__mod_1_1fstarpu__codelet__set__flags.html":[26,0,0,31],
"interfacefstarpu__mod_1_1fstarpu__codelet__set__max__parallelism.html":[27,0,0,32],
"interfacefstarpu__mod_1_1fstarpu__codelet__set__max__parallelism.html":[26,0,0,32],
"interfacefstarpu__mod_1_1fstarpu__codelet__set__model.html":[27,0,0,33],
"interfacefstarpu__mod_1_1fstarpu__codelet__set__model.html":[26,0,0,33],
"interfacefstarpu__mod_1_1fstarpu__codelet__set__name.html":[26,0,0,34],
"interfacefstarpu__mod_1_1fstarpu__codelet__set__name.html":[27,0,0,34]
};
